
This directory contains python scripts to benchmark our TK kernels and evaluate correctness. 

Organization: We have a separate directory for each TK kernel, containing two primary files:
1. `implementations.py` contains the 


### Installing baselines

We compare to baseline kernels from prior work. To install these:

*Attention*

```bash
```

*Long Convolution*
```bash
# Flash FFT Conv benchmark
pip install git+https://github.com/HazyResearch/flash-fft-conv.git#subdirectory=csrc/flashfftconv
```




